package com.urbancode.anthill3.plugin.scm

import com.urbancode.anthill3.*

import java.text.*;
import java.util.Date;

public class SCMCheckout extends SCMStep {

    //**************************************************************************
    // CLASS
    //**************************************************************************

    //**************************************************************************
    // INSTANCE
    //**************************************************************************

    Date date;

    /**
     *
     */
    public void execute() {
        initWorkspace();

        CommandHelper cmdHelper = getCommandHelperBase();

        // Convert date into revision
        if (!revision && date) {
            String dateString = getDateArgumentFormatter().format(date);
            revision = lookupRevision(date);
            println "Translated '$dateString' into $revision";
        }

        // switch off of branch to avoid `fatal: Cannot force update the current branch.`
        def coCmd = [scmCommand, '--no-pager', 'checkout', '--force', '--quiet', revision ?: remoteTrackingBranch]
        cmdHelper.runCommand('Git Checkout', coCmd)

        // create branch from the specified start point
        def branchCommand = [scmCommand, '--no-pager', 'branch', '--force', branch]
        if (revision) {
            branchCommand << revision
        }
        else {
            branchCommand << '--track' << remoteTrackingBranch;
        }
        cmdHelper.runCommand('Git Branch', branchCommand)

        def checkoutCommand = [scmCommand, '--no-pager', 'checkout', '--force', branch]
        cmdHelper.runCommand('Git Checkout', checkoutCommand)

        // translate symbolic revisions into sha1
        if (!revision || !(revision ==~ /[0-9a-fA-F]{40}/)) {
            println "Get revision id for workspace"
            def revisionCommand = [scmCommand, '--no-pager', 'rev-parse', '--verify', 'HEAD'];
            revision = getCommandText(revisionCommand);
            println("Using revision $revision");
        }
    }
}