#!/usr/bin/env groovy

import com.urbancode.anthill3.*
import com.urbancode.anthill3.plugin.scm.*
import java.text.*


final def dateParser = new DateParser();
final def ahpTool = new AHPTool();

//------------------------------------------------------------------------------
// PARSE PROPERTIES
//------------------------------------------------------------------------------

final def out = System.out
final def env = System.getenv()
final def props = ahpTool.getStepProperties();

final File workDir = new File('.').canonicalFile

final def stepProps = ahpTool.getStepProperties();


// Repo
final String scmCmd     = stepProps['source/repo/commandPath']
final String baseUrl    = stepProps['source/repo/repoBaseUrl']
final String username   = stepProps['source/repo/username']
final String password   = stepProps['source/repo/password']
final boolean httpsNoVerify = Boolean.valueOf(stepProps['source/repo/httpsNoVerify']);
final String changelogUserField = stepProps['source/repo/changelogUserField'];

// Source
final String srcName       = stepProps['source'];
final File dir          = new File(workDir, stepProps['source/dirOffset']).canonicalFile // get checkout directory
final String remoteName  = stepProps['source/remoteName']
final String remoteUrl  = stepProps['source/remoteUrl']
final String branch     = stepProps['source/branch']
final String userExcludesString = stepProps['source/excludeUsers'] ?: ''
final String fileFiltersString  = stepProps['source/fileFilters'] ?: '';

// Step
final def startRevision = stepProps['startRevision'] ?: ''
final def endRevision   = stepProps['endRevision'] ?: ''
final def startDate     = dateParser.parseDate(stepProps['startDate'])
final def endDate       = dateParser.parseDate(stepProps['endDate'])

//
// Execute
//

SCMQuietPeriod quietPeriod = new SCMQuietPeriod();
quietPeriod.directory  = dir;
quietPeriod.scmCommand = scmCmd;
quietPeriod.remoteBaseUrl  = baseUrl;
quietPeriod.remoteUser = username;
quietPeriod.remotePass = password;
quietPeriod.httpsNoVerify  = httpsNoVerify;
quietPeriod.changelogUserField = changelogUserField;
quietPeriod.remoteUrl  = remoteUrl;
quietPeriod.remoteName = remoteName;
quietPeriod.branch     = branch;

quietPeriod.startRevision = startRevision
quietPeriod.endRevision = endRevision
quietPeriod.startDate = startDate
quietPeriod.endDate = endDate

quietPeriod.changeSetFilter.setUserExcludes(userExcludesString);
quietPeriod.changeSetFilter.setFileFilters(fileFiltersString);

Date latestRevisionDate = quietPeriod.execute()

//------------------------------------------------------------------------------
// UPLOAD LATEST CHANGE DATE
//------------------------------------------------------------------------------
if (latestRevisionDate == null) {
    println('No changes detected')
}
else {
    ahpTool.setQuietPeriodLatestTime(latestRevisionDate.time)
    println('')
}
